@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.111';
+our $VERSION = '0.112';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sat Oct 27 12:17:42 2018 GMT
+# on Thu Nov  8 14:20:42 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1732,7 +1732,7 @@ __PACKAGE__->status( add => 25105, iridium => '-', 'Iridium 24', 'Tumbling' );
 __PACKAGE__->status( add => 25106, iridium => 'D', 'Iridium 47', 'Decayed 2018-09-01' );
 __PACKAGE__->status( add => 25107, iridium => 'D', 'Iridium 48', 'Decayed 2001-05-05' );
 __PACKAGE__->status( add => 25108, iridium => 'D', 'Iridium 49', 'Decayed 2018-02-13' );
-__PACKAGE__->status( add => 25169, iridium => '-', 'Iridium 52', 'Tumbling' );
+__PACKAGE__->status( add => 25169, iridium => 'D', 'Iridium 52', 'Decayed 2018-11-05' );
 __PACKAGE__->status( add => 25170, iridium => 'D', 'Iridium 56', 'Decayed 2018-10-11' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => 'D', 'Iridium 50', 'Decayed 2018-09-23' );
@@ -1744,7 +1744,7 @@ __PACKAGE__->status( add => 25273, iridium => '-', 'Iridium 57', 'Tumbling' );
 __PACKAGE__->status( add => 25274, iridium => 'S', 'Iridium 58', '' );
 __PACKAGE__->status( add => 25275, iridium => '+', 'Iridium 59', '' );
 __PACKAGE__->status( add => 25276, iridium => '+', 'Iridium 60', '' );
-__PACKAGE__->status( add => 25285, iridium => '-', 'Iridium 62', 'Tumbling' );
+__PACKAGE__->status( add => 25285, iridium => 'D', 'Iridium 62', 'Decayed 2018-11-07' );
 __PACKAGE__->status( add => 25286, iridium => '-', 'Iridium 63', 'Tumbling' );
 __PACKAGE__->status( add => 25287, iridium => 'S', 'Iridium 64', '' );
 __PACKAGE__->status( add => 25288, iridium => 'D', 'Iridium 65', 'Decayed 2018-07-19' );
@@ -1768,8 +1768,8 @@ __PACKAGE__->status( add => 25471, iridium => 'D', 'Iridium 77', 'Decayed 2017-0
 __PACKAGE__->status( add => 25527, iridium => '-', 'Iridium 2', 'Tumbling' );
 __PACKAGE__->status( add => 25528, iridium => 'D', 'Iridium 86', 'Decayed 2018-10-05' );
 __PACKAGE__->status( add => 25529, iridium => 'D', 'Iridium 85', 'Decayed 2000-12-30' );
-__PACKAGE__->status( add => 25530, iridium => '-', 'Iridium 84', 'Tumbling' );
-__PACKAGE__->status( add => 25531, iridium => '-', 'Iridium 83', 'Tumbling' );
+__PACKAGE__->status( add => 25530, iridium => 'D', 'Iridium 84', 'Decayed 2018-11-04' );
+__PACKAGE__->status( add => 25531, iridium => 'D', 'Iridium 83', 'Decayed 2018-11-05' );
 __PACKAGE__->status( add => 25577, iridium => 'D', 'Iridium 20', 'Decayed 2018-10-22' );
 __PACKAGE__->status( add => 25578, iridium => 'D', 'Iridium 11', 'Decayed 2018-10-22' );
 __PACKAGE__->status( add => 25777, iridium => '+', 'Iridium 14', '' );
@@ -1785,8 +1785,8 @@ __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-0
 # Summary:
 # Operational [+]: 8
 #       Spare [S]: 7
-#    Tumbling [-]: 37
-#     Decayed [D]: 45
+#    Tumbling [-]: 33
+#     Decayed [D]: 49
 
 1;
 
